==> 5dim_energy_0.15.7.zip: 5dim_energy_0.15.7/prototypes/small-pump-2.lua <==
data:extend({
-- Item
  {
    type = "item",
    name = "5d-small-pump",
    icon = "__5dim_energy__/graphics/icon/icon_5dim_small-pump_2_.png",
    flags = {"goes-to-quickbar"},
    subgroup = "energy-small-pump",
    order = "b",
    place_result = "5d-small-pump",
    stack_size = 50
  },

--Recipe
  {
    type = "recipe",
    name = "5d-small-pump",
    energy_required = 2,
    enabled = "false",
    ingredients =
    {
      {"electric-engine-unit", 2},
      {"steel-plate", 10},
      {"pump", 1},
      {"pipe", 2}
    },
    result= "5d-small-pump"
  },

--Entity
  {
    type = "pump",
    name = "5d-small-pump",
    icon = "__5dim_energy__/graphics/icon/icon_5dim_small-pump_2_.png",
    flags = {"placeable-neutral", "player-creation"},
    minable = {mining_time = 1, result = "5d-small-pump"},
    max_health = 80,
    fast_replaceable_group = "pipe",
    corpse = "small-remnants",
    resistances =
    {
      {
        type = "fire",
        percent = 70
      }
    },
    collision_box = {{-0.29, -0.29}, {0.29, 0.29}},
    selection_box = {{-0.5, -0.5}, {0.5, 0.5}},
    fluid_box =
    {
      base_area = 1.2,
      pipe_covers = pipecoverspictures(),
      pipe_connections =
      {
        { position = {0, -1}, type="output" },
        { position = {0, 1}, type="input" },
      },
    },
    energy_source =
    {
      type = "electric",
      usage_priority = "secondary-input",
      emissions = 0.01 / 2.5
    },
    energy_usage = "90kW",
    pumping_speed = 600,
    animations =
    {
      north =
      {
        filename = "__5dim_energy__/graphics/icon/icon_5d_small-pump-up_2.png",
        width = 46,
        height = 56,
        frame_count = 8,
        shift = {0.09375, 0.03125},
        animation_speed = 0.5
      },
      east =
      {
        filename = "__5dim_energy__/graphics/icon/icon_5d_small-pump-right_2.png",
        width = 51,
        height = 56,
        frame_count = 8,
        shift = {0.265625, -0.21875},
        animation_speed = 0.5
      },
      south =
      {
        filename = "__5dim_energy__/graphics/icon/icon_5d_small-pump-down_2.png",
        width = 61,
        height = 58,
        frame_count = 8,
        shift = {0.421875, -0.125},
        animation_speed = 0.5
      },
      west =
      {
        filename = "__5dim_energy__/graphics/icon/icon_5d_small-pump-left_2.png",
        width = 56,
        height = 44,
        frame_count = 8,
        shift = {0.3125, 0.0625},
        animation_speed = 0.5
      }
    },
    circuit_wire_connection_points =
    {
      {
        shadow =
        {
          red = {0.171875, 0.140625},
          green = {0.171875, 0.265625},
        },
        wire =
        {
          red = {-0.53125, -0.15625},
          green = {-0.53125, 0},
        }
      },
      {
        shadow =
        {
          red = {0.890625, 0.703125},
          green = {0.75, 0.75},
        },
        wire =
        {
          red = {0.34375, 0.28125},
          green = {0.34375, 0.4375},
        }
      },
      {
        shadow =
        {
          red = {0.15625, 0.0625},
          green = {0.09375, 0.125},
        },
        wire =
        {
          red = {-0.53125, -0.09375},
          green = {-0.53125, 0.03125},
        }
      },
      {
        shadow =
        {
          red = {0.796875, 0.703125},
          green = {0.625, 0.75},
        },
        wire =
        {
          red = {0.40625, 0.28125},
          green = {0.40625, 0.4375},
        }
      }
    },
    circuit_connector_sprites =
    {
      get_circuit_connector_sprites({-0.40625, -0.3125}, nil, 24),
      get_circuit_connector_sprites({0.125, 0.21875}, {0.34375, 0.40625}, 18),
      get_circuit_connector_sprites({-0.40625, -0.25}, nil, 24),
      get_circuit_connector_sprites({0.203125, 0.203125}, {0.25, 0.40625}, 18),
    },
    circuit_wire_max_distance = 7.5
  },
})

==> 5dim_energy_0.16.8.zip: 5dim_energy_0.16.8/prototypes/small-pump-2.lua <==
data:extend({
-- Item
  {
    type = "item",
    name = "5d-small-pump",
    icon = "__5dim_energy__/graphics/icon/icon_5dim_small-pump_2_.png",
    flags = {"goes-to-quickbar"},
    icon_size = 32,
    subgroup = "energy-small-pump",
    order = "b",
    place_result = "5d-small-pump",
    stack_size = 50
  },

--Recipe
  {
    type = "recipe",
    name = "5d-small-pump",
    energy_required = 2,
    enabled = "false",
    ingredients =
    {
      {"electric-engine-unit", 2},
      {"steel-plate", 10},
      {"pump", 1},
      {"pipe", 2}
    },
    result= "5d-small-pump"
  },

--Entity
  {
    type = "pump",
    name = "5d-small-pump",
    icon = "__5dim_energy__/graphics/icon/icon_5dim_small-pump_2_.png",
    flags = {"placeable-neutral", "player-creation"},
    minable = {mining_time = 1, result = "5d-small-pump"},
    icon_size = 32,
    max_health = 80,
    fast_replaceable_group = "pipe",
    corpse = "small-remnants",
    resistances =
    {
      {
        type = "fire",
        percent = 70
      }
    },
    collision_box = {{-0.29, -0.29}, {0.29, 0.29}},
    selection_box = {{-0.5, -0.5}, {0.5, 0.5}},
    fluid_box =
    {
      base_area = 1.2,
      pipe_covers = pipecoverspictures(),
      pipe_connections =
      {
        { position = {0, -1}, type="output" },
        { position = {0, 1}, type="input" },
      },
    },
    energy_source =
    {
      type = "electric",
      usage_priority = "secondary-input",
      emissions = 0.01 / 2.5
    },
    energy_usage = "90kW",
    pumping_speed = 600,
    animations =
    {
      north =
      {
        filename = "__5dim_energy__/graphics/icon/icon_5d_small-pump-up_2.png",
        width = 46,
        height = 56,
        frame_count = 8,
        shift = {0.09375, 0.03125},
        animation_speed = 0.5
      },
      east =
      {
        filename = "__5dim_energy__/graphics/icon/icon_5d_small-pump-right_2.png",
        width = 51,
        height = 56,
        frame_count = 8,
        shift = {0.265625, -0.21875},
        animation_speed = 0.5
      },
      south =
      {
        filename = "__5dim_energy__/graphics/icon/icon_5d_small-pump-down_2.png",
        width = 61,
        height = 58,
        frame_count = 8,
        shift = {0.421875, -0.125},
        animation_speed = 0.5
      },
      west =
      {
        filename = "__5dim_energy__/graphics/icon/icon_5d_small-pump-left_2.png",
        width = 56,
        height = 44,
        frame_count = 8,
        shift = {0.3125, 0.0625},
        animation_speed = 0.5
      }
    },
    circuit_wire_connection_points =
    {
      {
        shadow =
        {
          red = {0.171875, 0.140625},
          green = {0.171875, 0.265625},
        },
        wire =
        {
          red = {-0.53125, -0.15625},
          green = {-0.53125, 0},
        }
      },
      {
        shadow =
        {
          red = {0.890625, 0.703125},
          green = {0.75, 0.75},
        },
        wire =
        {
          red = {0.34375, 0.28125},
          green = {0.34375, 0.4375},
        }
      },
      {
        shadow =
        {
          red = {0.15625, 0.0625},
          green = {0.09375, 0.125},
        },
        wire =
        {
          red = {-0.53125, -0.09375},
          green = {-0.53125, 0.03125},
        }
      },
      {
        shadow =
        {
          red = {0.796875, 0.703125},
          green = {0.625, 0.75},
        },
        wire =
        {
          red = {0.40625, 0.28125},
          green = {0.40625, 0.4375},
        }
      }
    },
    circuit_wire_connection_points = circuit_connector_definitions["pump"].points,
    circuit_connector_sprites = circuit_connector_definitions["pump"].sprites,
    circuit_wire_max_distance = default_circuit_wire_max_distance
  },
})
